// ----------------------------------------------------------------------------
// Copyright (C) 2020
//              David Freese, W1HKJ
//
// This file is part of flrig.
//
// flrig is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// flrig is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------

#ifndef GPIO_H
#define GPIO_H

#include <FL/Fl.H>
#include <FL/Fl_Group.H>
#include <FL/Fl_Box.H>
#include <FL/Fl_Input.H>
#include <FL/Fl_Check_Button.H>
#include <FL/Fl_Check_Button.H>

//#include <FL/Fl_Counter.H>
//extern Fl_Check_Button *btn_enable_gpio[17];
//extern Fl_Check_Button *btn_gpio_on[17];
//extern Fl_Counter      *cnt_gpio_pulse_width;

extern Fl_Input *gpio_ptt_dev;
extern Fl_Button *btn_select_gpio_ptt;
extern Fl_Int_Input *gpio_ptt_line;
extern Fl_Check_Button *btn_enable_gpio_ptt;
extern Fl_Input *gpio_cw_dev;
extern Fl_Button *btn_select_gpio_cw;
extern Fl_Int_Input *gpio_cw_line;
extern Fl_Check_Button *btn_enable_gpio_cw;


extern Fl_Group *createGPIO(int X, int Y, int W, int H, const char *label);

#endif
